#pragma once

#define _MSG_INSIDE

#include <drive/msg-drive.h>
#include <drive/msg-drive-item.h>
#include <drive/msg-drive-item-file.h>
#include <drive/msg-drive-item-folder.h>
#include <drive/msg-drive-service.h>
#include <mail/msg-mail-folder.h>
#include <mail/msg-mail-message.h>
#include <mail/msg-mail-service.h>
#include <user/msg-user.h>
#include <user/msg-user-service.h>
#include <msg-authorizer.h>
#include <msg-error.h>
#include <msg-goa-authorizer.h>
#include <msg-private.h>
